summaryrefslogtreecommitdiffstats
path: root/kmymoney2/dialogs/kaccountselectdlg.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/dialogs/kaccountselectdlg.h')
-rw-r--r--kmymoney2/dialogs/kaccountselectdlg.h25
1 files changed, 13 insertions, 12 deletions
diff --git a/kmymoney2/dialogs/kaccountselectdlg.h b/kmymoney2/dialogs/kaccountselectdlg.h
index 271cd0f..180587e 100644
--- a/kmymoney2/dialogs/kaccountselectdlg.h
+++ b/kmymoney2/dialogs/kaccountselectdlg.h
@@ -26,8 +26,8 @@
// ----------------------------------------------------------------------------
// QT Includes
-#include <qwidget.h>
-#include <qstring.h>
+#include <tqwidget.h>
+#include <tqstring.h>
// ----------------------------------------------------------------------------
// KDE Includes
@@ -47,8 +47,9 @@
class KAccountSelectDlg : public KAccountSelectDlgDecl
{
Q_OBJECT
+ TQ_OBJECT
public:
- KAccountSelectDlg(const KMyMoneyUtils::categoryTypeE type, const QString& purpose = "General", QWidget *parent=0, const char *name=0);
+ KAccountSelectDlg(const KMyMoneyUtils::categoryTypeE type, const TQString& purpose = "General", TQWidget *tqparent=0, const char *name=0);
~KAccountSelectDlg();
/**
@@ -56,9 +57,9 @@ public:
* selection dialog box. The @p msg should contain a descriptive
* text about the purpose of the dialog and it's options.
*
* @param msg const reference to QString object containing the text.
*/
- void setDescription(const QString& msg);
+ void setDescription(const TQString& msg);
/**
* This method is used to setup the buddy text of the account
@@ -66,9 +67,9 @@ public:
* which is placed above the selection box with the account
* names.
*
* @param msg const reference to QString object containing the text.
*/
- void setHeader(const QString& msg);
+ void setHeader(const TQString& msg);
/**
* This method is used to pass information to the account selection
@@ -78,14 +79,14 @@ public:
* @param account MyMoneyAccount filled with the relevant and available information
* @param id account id to be used.
*/
- void setAccount(const MyMoneyAccount& account, const QString& id);
+ void setAccount(const MyMoneyAccount& account, const TQString& id);
/**
* This method returns the name of the selected account in the combo box.
*
* @return QString containing the id of the selected account
*/
- const QString& selectedAccount(void) const;
+ const TQString& selectedAccount(void) const;
/**
* This method is used to set the mode of the dialog. Two modes
@@ -117,7 +118,7 @@ public:
public slots:
/**
- * Reimplemented from QDialog
+ * Reimplemented from TQDialog
*/
int exec();
@@ -145,7 +146,7 @@ protected slots:
void slotReloadWidget(void);
private:
- QString m_purpose;
+ TQString m_purpose;
MyMoneyAccount m_account;
int m_mode; // 0 - select or create, 1 - create only
KMyMoneyUtils::categoryTypeE m_accountType;
@@ -56,9 +57,9 @@ public:
* text about the purpose of the dialog and it's options.
*
- * @param msg const reference to QString object containing the text.
+ * @param msg const reference to TQString object containing the text.
*/
@@ -66,9 +67,9 @@ public:
* names.
*
- * @param msg const reference to QString object containing the text.
+ * @param msg const reference to TQString object containing the text.
*/
@@ -78,14 +79,14 @@ public:
* This method returns the name of the selected account in the combo box.
*
- * @return QString containing the id of the selected account
+ * @return TQString containing the id of the selected account
*/